library(ggplot2)
library(reshape2)
library(plyr)
library(lme4)
library(MASS)

rm(list=ls())



RKstats <- function(x) c(M=mean(x), SD=sd(x), N=length(x), SE=sd(x)/sqrt(length(x)) )

vplayout <- function(x, y) {
viewport(layout.pos.row = x, layout.pos.col = y) 
}

load("stim2.rda")   
str(gd)

gd$aoi <- as.numeric(gd$aoi)
gd <- gd[which(gd$aoi>1 & gd$aoi<30),]
gd$block   <- as.factor(ifelse(gd$trialid>200,2,1)) # 1= digit, 2= dice
gd$group   <- as.factor(ifelse(gd$subj<200,2,1)) # control = 2 ; dyslexic = 1
gd$cond    <- as.factor(ifelse(gd$group=='2',ifelse(gd$block=='1',1,2),ifelse(gd$block=='1',3,4)))
gd$block <- factor(gd$block, levels=c(1,2),labels=c("digit","dice"))
gd$group <- factor(gd$group, levels=c(1,2),labels=c("dyslexic","control"))
gd$subj    <- as.factor(gd$subj)
gd$trial <- as.numeric(gd$trial)
gd$trialid <- as.factor(gd$trialid)
gd$lx <- as.numeric(gd$lx)
gd$lxs     <- gd$lx/116
gd$skip    <- ifelse(gd$nfix==0, 1, 0)
gd$refix   <- ifelse(gd$nfix>1, 1, 0)
gd$fixdur <- as.numeric(gd$fixdur)
gd$item <- as.factor(gd$item)

cmat.t4 <- matrix(c(0.5,0.5,-0.5,-0.5, # nor vs dys
                    0.5,-0.5,0.5,-0.5, # dig vs dic
                    0.5,-0.5,-0.5,0.5  # interaction
                    ), 4,3,dimnames=list(c("nor_dig", "nor_dic", "dys_dig", "dys_dic"), 
	                                c("group", "stim", "interaction")))

contrasts(gd$cond) <- cmat.t4

# first and last units in a row
gd$aoi_2 <- ifelse(gd$aoi%%10==0 | gd$aoi%%10==1, 0, 1)
length(which(gd$blink==0 & gd$aoi_2==1))/length(which(gd$aoi_2==1))

gd0 = gd[which(gd$fixdur>60 & gd$fixdur<800 & gd$gaze>60 & gd$gaze<1000 & gd$aoi_2==1),]
gd1 = gd[which(gd$fixdur>60 & gd$fixdur<800 & gd$gaze>60 & gd$gaze<1000 & gd$aoi_2==1 & gd$blink==0),]
nrow(gd1)/nrow(gd0)

# SFD
summary(m1.SFD <- lmer(log(gaze) ~ cond + (1 | item) + (1 | subj), data=gd1, subset=nfix==1))
summary(lmer(log(gaze) ~ group + (1 | item) + (1 | subj), data=gd1, subset=nfix==1 & block=='digit'))
summary(lmer(log(gaze) ~ group + (1 | item) + (1 | subj), data=gd1, subset=nfix==1 & block=='dice'))

# FFD
summary(m1.FFD <- lmer(log(fixdur) ~ cond + (1 | item) + (1 | subj), data=gd1))
summary(lmer(log(fixdur) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='digit'))
summary(lmer(log(fixdur) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='dice'))

# GD
summary(m1.GD  <- lmer(log(gaze) ~ cond + (1 | item) + (1 | subj), data=gd1))
summary(lmer(log(gaze) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='digit'))
summary(lmer(log(gaze) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='dice'))

# LP-SF
summary(m2.SF <- lmer(lxs ~ cond + (1 | item) + (1 | subj), data=gd1, subset=nfix==1))
summary(lmer(lxs ~ group + (1 | item) + (1 | subj), data=gd1, subset=nfix==1 & block=='digit'))
summary(lmer(lxs ~ group + (1 | item) + (1 | subj), data=gd1, subset= nfix==1 & block=='dice'))

# LP-FF
summary(m2.FF <- lmer(lxs ~ cond +  (1 | item) + (1 | subj), data=gd1))
summary(lmer(lxs ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='digit'))
summary(lmer(lxs ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='dice'))


# SAC
summary(m3.SAC <- lmer( (sacdx/116) ~ cond +  (1 | item) + (1 | subj), data=gd1, subset=sacdx>0))
summary(lmer( (sacdx/116) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='digit' & sacdx>0))
summary(lmer( (sacdx/116) ~ group + (1 | item) + (1 | subj), data=gd1, subset=block=='dice' & sacdx>0))

# SFD
temp1 <- ddply(gd1[gd1$nfix==1,],c("subj","group","block"),with,each(M=mean)(gaze))
ddply(temp1,c("group","block"),with,each(RKstats)(M))

#FFD
temp1 <- ddply(gd1,c("subj","group","block"),with,each(M=mean)(fixdur))
(M.2 <- ddply(temp1,c("group","block"),with,each(RKstats)(M)))

#GD
temp1 <- ddply(gd1,c("subj","group","block"),with,each(M=mean)(gaze))
ddply(temp1,c("group","block"),with,each(RKstats)(M))

#SA
gd1$sac<-gd1$sacdx/116
temp1 <- ddply(gd1[gd1$sacdx>0,],c("subj","group","block"),with,each(M=mean)(sac))
ddply(temp1,c("group","block"),with,each(RKstats)(M))

#SLP
temp1 <- ddply(gd1[gd1$nfix==1,],c("subj","group","block"),with,each(M=mean)(lxs))
ddply(temp1,c("group","block"),with,each(RKstats)(M))

#FLP
temp1 <- ddply(gd1,c("subj","group","block"),with,each(M=mean)(lxs))
ddply(temp1,c("group","block"),with,each(RKstats)(M))